# Copyright 2022 Alvaro Bartolome, alvarobartt @ GitHub
# See LICENSE for details.

"""`investiny `: `investpy` but made tiny."""

__author__ = "Alvaro Bartolome, alvarobartt @ GitHub"
__version__ = "0.1.0"

from investiny.historical import historical_data  # noqa: F401
